//----------------------------------------------------------------------------
/// \file 
/// Header File for TBarCode DLL (Windows) and TBarCode/X (UNIX).
/// Include this header file in your modules to access the TBarCode API.
/// In Windows: 
/// \code
/// #include "tbarcode.h"
/// \endcode
/// In Linux/Unix:
/// \code
/// #include <libtbarcode7/tbarcode.h>
/// \endcode
/// \n
/// The TBarCode DLL (Windows) and TBarCode/X basically have the same
/// API except for some functions:
/// - Functions denoted with "Windows only" belong 
/// to the TBarCode DLL API and are only available in Windows.
/// - Functions denoted with "UNIX only" belong to the TBarCode/X API and are 
/// only available in UNIX/Linux environments.
/// \n
/// \author TEC-IT Datenverarbeitung GmbH \n
///   Wagnerstr. 6, A-4400 Steyr, AUSTRIA/EUROPE \n
///   http://www.tec-it.com \n
///   Copyright &copy; 1996 - 2006 by TEC-IT Datenverarbeitung GmbH 
/// \version 7.0
/// \note This product is supported. Please send an email to support@tec-it.com
//----------------------------------------------------------------------------
#ifndef TBARCODE_HEADER
#  define TBARCODE_HEADER

//
// Define TEC_WIN symbols on Windows platforms OR TEC_UNIX on Linux/Unix platforms.
//
#if defined(WIN32) || defined(_WIN32) || defined(_WIN32_WCE) || defined(WIN64) || defined(_WIN64)
  /// Defined if platform is Windows.
  /// \internal
  #define TEC_WIN 1
  #if defined(UNDER_CE) || defined(_WIN32_WCE)
    /// Defined if platform is Windows CE.
    /// \internal
    #define TEC_WINCE 1
  #else
    /// Defined if platform is a 32-bit Windows.
    /// \internal
    #define TEC_WIN32 1
  #endif
#else
  /// Defined if platform is Windows.
  /// \internal
  #define TEC_UNIX 1
#endif


#ifdef TEC_WIN  
  #include <windows.h>
#else
  #include <wchar.h>
  #include "TECITStd/TECDataTypes.h"
  #include "TECITStd/TECWinError.h"
#endif

/// Current TBarCode version.
#define TBARCODE_VERSION "7.0.1"
/// Symbol that identifies TBarCode 7.0.1.
#define TBARCODE_7_0_1


//
// Set symbol TECIT_STDCALL to appropriate calling convention statement.
//
#ifdef TEC_WIN
  #undef TECIT_STDCALL
  /// Defines calling convention.
  /// \internal
  #define TECIT_STDCALL _stdcall
#else
  #undef TECIT_STDCALL
  /// Defines calling convention.
  /// \internal
  #define TECIT_STDCALL
#endif

//
// Set symbol TBARCODEDLL_API to appropriate DLL export or import statement.
//
#if defined(TEC_WIN) && defined (TBARCODE_DLLEXPORT)
  /// Exports/imports DLL interface.
  /// \internal
	#define TBARCODEDLL_API __declspec(dllexport)
#elif defined(TEC_WIN) && !defined(TBARCODE_STATICLIB)
  /// Exports/imports DLL interface.
  /// \internal
	#define TBARCODEDLL_API  __declspec(dllimport)
#else
  /// Exports/imports DLL interface.
  /// \internal
	#define TBARCODEDLL_API
#endif


#define TEC_MAX_INPUT 10000

#include "tecbcenum.h"


#ifdef __cplusplus
  extern "C"
  {
#endif


//____________________________________________________________________________
//
// Constants, Structures, Types
//____________________________________________________________________________
//

#ifndef S_OK
  #define S_OK      ((HRESULT) 0x00000000L)
  #define S_FALSE   ((HRESULT) 0x00000001L)
#endif

/// Constant indicating a default value.
/// Used for determining or setting the default value of most relevant parameters.
#define BC_USEDEFAULT   -1

/// Forward declaration of the internal used barcode structure.
/// The exact layout of this structure is hidden.
typedef struct tag_BarCode  t_BarCode;


#ifndef ERRCODE
/// Data-type for error-codes.
/// Error-code 0 indicates successful operation
#define ERRCODE LONG
#define ErrOk S_OK
#endif


//____________________________________________________________________________
//
// Misc Function Calls
//____________________________________________________________________________
//
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCGetLibraryVersion(INT* pMajor, INT* pMinor, INT* pRelease, INT* pRevision, LPCSTR* pszVersion, LPCSTR* pszBuildDate);



/**
 * Callback-function which is called instead of drawing a barcode row.
 * This callback function can be set with BCSetFuncDrawRow(). When set the drawing 
 * functions such as BCDraw(), BCPostscriptToFile, BCPCLToFile() etc. do not generate 
 * any output. Instead they call the active callback function.\n
 * When Windows-GDI drawing is startet (with BCDraw()) then drawDC, targetDC contain the 
 * Windows device contexts (if set). \n
 * The parameters x, y, width, and height specify the extent
 * of the barcode row. If drawDC and targetDC are not set then these variables are given in millimeters,
 * where the origin of the coordinate system is the upper, left coordinate of the barcode. The positive X-axis
 * points to the right and the positive Y-axis points downwards.\n
 * If drawDC or targetDC are set then the parameters x, y, width, and height use the current logical 
 * coordinate system and the logical units of these device contexts.\n
 * In your callback function you can use BCGetMetaData() to query the bars and spaces of the current row.
 * \note A barcode row in this case is a single row of bars. Linear (1-dimensional) barcodes 
 * have exactly one row of bars. 2-dimensional barcodes can have more than one row of bars: In this 
 * case this callback function is called once for each row.
 * \note The user-defined data (customData) is shared by all callback functions.
 * \note The TBarCode Callback functions can be used only with a developer license. Sample code is available on request: support@tec-it.com
 * \param[in,out]  customData  User-defined data.
 * \param[in,out]  barcode     The handle of the barcode.
 * \param[in,out]  drawDC      The device context.
 * \param[in,out]  targetDC    The target device context.
 * \param[in]  x       The left coordinate of the row.
 * \param[in]  y       The top coordinate of the row.
 * \param[in]  width   The width of the row.
 * \param[in]  height  The height of the row.
 * \retval     ErrOk   Everything went fine, and the drawing continues.
 * \retval     !=ErrOk Something went wrong, the drawing function returns with the returned error value.
 * \see BCGetFuncDrawRow(), BCSetFuncDrawRow(), BCDrawCB(), BCGetMetaData()
 */
typedef ERRCODE (CALLBACK *fn_DrawRow) (VOID* customData, t_BarCode* barcode, HDC drawDC, HDC targetDC, DOUBLE x, DOUBLE y, DOUBLE width, DOUBLE height);


/**
 * Data-type for custom bar-drawing callback-function.
 * This callback function can be set with BCSetFuncDrawBar(). When set the drawing 
 * functions such as BCDraw(), BCPostscriptToFile, BCPCLToFile() etc. do not generate 
 * any output. Instead they call the active callback function. This function is called once for each bar.\n
 * When Windows-GDI drawing is startet (with BCDraw()) then drawDC contains the 
 * Windows device contexts (if set). The variables x, y, width, and height specify the extent
 * of the bar. If drawDC and targetDC are not set then these variables are given in millimeters,
 * where the origin of the coordinate system is the upper, left coordinate of the barcode. The positive X-axis
 * points to the right and the positive Y-axis points downwards.\n
 * If drawDC or targetDC are set then the parameters x, y, width, and height use the current logical 
 * coordinate system and the logical units of these device contexts.\n
 * \note The user-defined data (customData) is shared by all callback functions.
 * \note The TBarCode Callback functions can be used only with a developer license. Sample code is available on request: support@tec-it.com
 * \param[in,out]  customData  User-defined data.
 * \param[in,out]  barcode     The handle of the barcode.
 * \param[in,out]  drawDC      The device context.
 * \param[in]  x       The left coordinate of the row.
 * \param[in]  y       The top coordinate of the row.
 * \param[in]  width   The width of the row.
 * \param[in]  height  The height of the row.
 * \retval     ErrOk   Everything went fine, and the drawing continues.
 * \retval     !=ErrOk Something went wrong, the drawing function returns with the returned error value.
 * \see BCGetFuncDrawBar(), BCSetFuncDrawBar(), BCDrawCB()
 */
typedef ERRCODE (CALLBACK *fn_DrawBar)  (VOID* customData, HDC drawDC, DOUBLE x, DOUBLE y, DOUBLE width, DOUBLE height);


/**
 * Data-type for custom human readable text drawing callback-function.
 * This callback function can be set with BCSetFuncDrawText(). When set the drawing 
 * functions such as BCDraw(), BCPostscriptToFile, BCPCLToFile() etc. do not generate 
 * any output. Instead they call the active callback function.\n
 * When Windows-GDI drawing is startet (with BCDraw()) then drawDC contains the 
 * Windows device contexts (if set). The variables x, and y specify the position
 * of the barcode text. If drawDC and targetDC are not set then these variables are given in millimeters,
 * where the origin of the coordinate system is the upper, left coordinate of the barcode. The positive X-axis
 * points to the right and the positive Y-axis points downwards.\n
 * If drawDC or targetDC are set then the parameters x and y use the current logical 
 * coordinate system and the logical units of these device contexts.\n
 * \note The user-defined data (customData) is shared by all callback functions.
 * \param[in,out]  customData  User-defined data.
 * \param[in,out]  barcode     The handle of the barcode.
 * \param[in,out]  drawDC      The device context.
 * \param[in]  font    The LOGFONTA structure that defines the font.
 * \param[in]  x       The x-coordinate of the text. Depending on the alignment, the x specifies either the left, the center or the right coordinate of the text.
 * \param[in]  y       The top coordinate of the text.
 * \param[in]  alignment The horizontal alignment of the text. (The vertical alignment is always 'top'.)
 * \param[in]  text    The output string.
 * \param[in]  numberOfCharacters  The number of charactes in text.
 * \retval     ErrOk   Everything went fine, and the drawing continues.
 * \retval     !=ErrOk Something went wrong, the drawing function returns with the returned error value.
 * \see BCGetFuncDrawText(), BCSetFuncDrawText(), BCDrawCB()
 */
typedef ERRCODE (CALLBACK *fn_DrawText) (VOID* customData, HDC drawDC, LPLOGFONTA font, DOUBLE x, DOUBLE y, e_BCAlign alignment, LPCSTR text, INT numberOfCharacters);


//____________________________________________________________________________
//
// Required Function Calls
//____________________________________________________________________________
//
#ifdef TEC_WIN32
TBARCODEDLL_API BOOL TECIT_STDCALL BCAttach();
TBARCODEDLL_API BOOL TECIT_STDCALL BCAttachInstance(HINSTANCE hInstance);
TBARCODEDLL_API BOOL TECIT_STDCALL BCDetach();
#endif 

#if defined(TEC_UNIX) || defined(TBARCODE_STATICLIB) || defined(TEC_WINCE)
  #if defined(TEC_WINCE)
    TBARCODEDLL_API ERRCODE TECIT_STDCALL BCInitLibrary(LPCWSTR szPath);
  #else
    TBARCODEDLL_API ERRCODE TECIT_STDCALL BCInitLibrary(LPCSTR szPath);
  #endif
  TBARCODEDLL_API ERRCODE TECIT_STDCALL BCDeInitLibrary();
#endif 

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCAlloc(t_BarCode** pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCFree(t_BarCode* pBarCode);

#if defined(TEC_WINCE)
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCLicenseMe(LPCWSTR lpszLicensee, e_licKind eKindOfLicense, 
                                                DWORD dwNoOfLicenses, LPCWSTR lpszKey, e_licProduct eProductID);
#else
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCLicenseMe(LPCSTR lpszLicensee, e_licKind eKindOfLicense, 
                                                DWORD dwNoOfLicenses, LPCSTR lpszKey, e_licProduct eProductID);
#endif

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCCreate(t_BarCode* pBarCode);



//____________________________________________________________________________
//
// Barcode Settings
//____________________________________________________________________________
//

//
// ----- Barcode > Barcode Type
//
TBARCODEDLL_API e_BarCType TECIT_STDCALL BCGetBCType(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetBCType(t_BarCode* pBarCode, e_BarCType eType);

TBARCODEDLL_API LPCSTR* TECIT_STDCALL BCGetBCList();
TBARCODEDLL_API LONG TECIT_STDCALL BCGetBCCount();

//
// ----- Barcode > Barcode Data
//
TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGetText(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetText(t_BarCode* pBarCode, LPCSTR szText, LONG nLen);
TBARCODEDLL_API LPCWSTR TECIT_STDCALL BCGetTextW(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetTextW(t_BarCode* pBarCode, LPCWSTR szText, LONG nLen);
TBARCODEDLL_API BOOL TECIT_STDCALL BCIsTextUnicode(t_BarCode* pBarCode);
TBARCODEDLL_API LONG TECIT_STDCALL BCGetTextLen(t_BarCode* pBarCode);

TBARCODEDLL_API e_Compression TECIT_STDCALL BCGetCompression(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetCompression(t_BarCode* pBarCode, e_Compression eCompression);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGetFormat(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetFormat(t_BarCode* pBarCode, LPCSTR szFormat);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGetTranslateEsc(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetTranslateEsc(t_BarCode* pBarCode, BOOL bTranslate);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCCheck(t_BarCode* pBarCode);
TBARCODEDLL_API LONG TECIT_STDCALL BCGetMaxLenOfData(e_BarCType eType);

//
// ----- Barcode > Appearance
//
TBARCODEDLL_API LONG TECIT_STDCALL BCGetBkMode(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetBkMode(t_BarCode* pBarCode, LONG nMode);

TBARCODEDLL_API LONG TECIT_STDCALL BCGetBearerBarWidth(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetBearerBarWidth(t_BarCode* pBarCode, LONG nBearerWidth);

TBARCODEDLL_API e_BearerBar TECIT_STDCALL BCGetBearerBarType(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetBearerBarType(t_BarCode* pBarCode, e_BearerBar eType);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGetMirror(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetMirror(t_BarCode* pBarCode, BOOL bMirror);

TBARCODEDLL_API LONG TECIT_STDCALL BCGetNotchHeight(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetNotchHeight(t_BarCode* pBarCode, LONG nHeight);

TBARCODEDLL_API e_Degree TECIT_STDCALL BCGetRotation(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetRotation(t_BarCode* pBarCode, e_Degree eRotation);

//
// ----- Barcode > Colors
//
TBARCODEDLL_API COLORREF TECIT_STDCALL BCGetColorBC(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetColorBC(t_BarCode* pBarCode, COLORREF color);

TBARCODEDLL_API COLORREF TECIT_STDCALL BCGetColorFont(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetColorFont(t_BarCode* pBarCode, COLORREF color);

TBARCODEDLL_API COLORREF TECIT_STDCALL BCGetColorBk(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetColorBk(t_BarCode* pBarCode, COLORREF color);

TBARCODEDLL_API e_ColorMode TECIT_STDCALL BCGetColorMode(const t_BarCode* pBarcode);
TBARCODEDLL_API VOID TECIT_STDCALL BCSetColorMode(t_BarCode* pBarcode, e_ColorMode mode);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetColorBC(t_BarCode* pBarcode, COLORREF color);
TBARCODEDLL_API COLORREF TECIT_STDCALL BCGetColorBC(t_BarCode* pBarCode);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetBarcodeColorCMYK(t_BarCode* pBarcode, DOUBLE dCyan, DOUBLE dMagenta, DOUBLE dYellow, DOUBLE dBlack);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetBarcodeColorCMYK(const t_BarCode* pBarcode, DOUBLE* pdCyan, DOUBLE* pdMagenta, DOUBLE* pdYellow, DOUBLE* pdBlack);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetBarcodeColorGDI(t_BarCode* pBarcode, COLORREF color);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetBarcodeColorGDI(const t_BarCode* pBarcode, COLORREF* pColor);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetBarcodeColorGray(t_BarCode* pBarcode, DOUBLE dGray);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetBarcodeColorGray(const t_BarCode* pBarcode, DOUBLE* pdGray);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetBarcodeColorRGB(t_BarCode* pBarcode, DOUBLE dRed, DOUBLE dGreen, DOUBLE dBlue);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetBarcodeColorRGB(const t_BarCode* pBarcode, DOUBLE* pdRed, DOUBLE* pdGreen, DOUBLE* pdBlue);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetBackgroundColorCMYK(t_BarCode* pBarcode, DOUBLE dCyan, DOUBLE dMagenta, DOUBLE dYellow, DOUBLE dBlack);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetBackgroundColorCMYK(const t_BarCode* pBarcode, DOUBLE* pdCyan, DOUBLE* pdMagenta, DOUBLE* pdYellow, DOUBLE* pdBlack);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetBackgroundColorGDI(t_BarCode* pBarcode, COLORREF color);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetBackgroundColorGDI(const t_BarCode* pBarcode, COLORREF* pColor);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetBackgroundColorGray(t_BarCode* pBarcode, DOUBLE dGray);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetBackgroundColorGray(const t_BarCode* pBarcode, DOUBLE* pdGray);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetBackgroundColorRGB(t_BarCode* pBarcode, DOUBLE dRed, DOUBLE dGreen, DOUBLE dBlue);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetBackgroundColorRGB(const t_BarCode* pBarcode, DOUBLE* pdRed, DOUBLE* pdGreen, DOUBLE* pdBlue);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetFontColorCMYK(t_BarCode* pBarcode, DOUBLE dCyan, DOUBLE dMagenta, DOUBLE dYellow, DOUBLE dBlack);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetFontColorCMYK(const t_BarCode* pBarcode, DOUBLE* pdCyan, DOUBLE* pdMagenta, DOUBLE* pdYellow, DOUBLE* pdBlack);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetFontColorGDI(t_BarCode* pBarcode, COLORREF color);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetFontColorGDI(const t_BarCode* pBarcode, COLORREF* pColor);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetFontColorGray(t_BarCode* pBarcode, DOUBLE dGray);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetFontColorGray(const t_BarCode* pBarcode, DOUBLE* pdGray);

TBARCODEDLL_API VOID TECIT_STDCALL BCSetFontColorRGB(t_BarCode* pBarcode, DOUBLE dRed, DOUBLE dGreen, DOUBLE dBlue);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetFontColorRGB(const t_BarCode* pBarcode, DOUBLE* pdRed, DOUBLE* pdGreen, DOUBLE* pdBlue);


//
// ----- Barcode > Print Ratio
//
TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGetRatio(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetRatio(t_BarCode* pBarCode, LPCSTR szRatio);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGetRatioHint(e_BarCType eType);
TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGetRatioString(e_BarCType eType);

TBARCODEDLL_API LONG TECIT_STDCALL BCGetCountBars(e_BarCType eBarCType);

TBARCODEDLL_API LONG TECIT_STDCALL BCGetCountSpaces(e_BarCType eBarCType);

//
// ----- Barcode > Quiet Zone
//
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetQuietZone(t_BarCode* pBarCode, LPRECT prQuietZone, e_QZMUnit eQZMUnit);
TBARCODEDLL_API LPCRECT TECIT_STDCALL BCGetQuietZone(t_BarCode* pBarCode);
TBARCODEDLL_API e_QZMUnit TECIT_STDCALL BCGetQuietZoneUnit(t_BarCode* pBarCode);


//
// ----- Barcode > Human Readable Text 
//
TBARCODEDLL_API LOGFONTA* TECIT_STDCALL BCGetLogFont(t_BarCode*  pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetLogFont(t_BarCode*  pBarCode, const LOGFONTA* lf);

TBARCODEDLL_API CHAR* TECIT_STDCALL BCGetFontName(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetFontName(t_BarCode* pBarCode, const CHAR* szName);

TBARCODEDLL_API INT TECIT_STDCALL BCGetFontHeight(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL  BCSetFontHeight(t_BarCode* pBarCode, INT nHeight);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetPrintText(t_BarCode* pBarCode, BOOL bReadable, BOOL bAbove);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGetTextAbove(t_BarCode* pBarCode);
TBARCODEDLL_API BOOL TECIT_STDCALL BCGetPrintText(t_BarCode* pBarCode);

TBARCODEDLL_API LONG TECIT_STDCALL BCGetTextDist(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetTextDist(t_BarCode* pBarCode, LONG nTextDist);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGetDisplayText(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetDisplayText(t_BarCode* pBarCode, LPCSTR szText);

TBARCODEDLL_API e_BCAlign TECIT_STDCALL BCGetTextAlignment(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetTextAlignment(t_BarCode* pBarCode, e_BCAlign eAlign);

//
// ----- Barcode > Check-Digits
//
TBARCODEDLL_API e_CDMethod TECIT_STDCALL BCGetCDMethod(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetCDMethod(t_BarCode* pBarCode, e_CDMethod eMethod);

TBARCODEDLL_API LONG TECIT_STDCALL BCGetCheckDigits(t_BarCode* pBarCode, LPSTR lpszCDText, LONG nSize);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCCalcCD(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCCalcCDExt (t_BarCode* pBarCode, LPCSTR lpszData, e_CDMethod eCDMethod, LPSTR lpszChecksum, LONG *nChecksum );

TBARCODEDLL_API e_CDMethod* TECIT_STDCALL BCGetCDListByType(e_BarCType eBCType);
TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGetNameFromEnum(e_CDMethod eCDMethod);
TBARCODEDLL_API LPCSTR* TECIT_STDCALL BCGetCDList();
TBARCODEDLL_API LONG TECIT_STDCALL BCGetCDCount();

//
// ----- Barcode > Size Queries
//
TBARCODEDLL_API LONG TECIT_STDCALL BCGet2D_XRows(const t_BarCode* pBarCode);
TBARCODEDLL_API LONG TECIT_STDCALL BCGet2D_XCols(const t_BarCode* pBarCode);
TBARCODEDLL_API DOUBLE TECIT_STDCALL BCGetCountModules(const t_BarCode* pBarCode);
TBARCODEDLL_API LONG TECIT_STDCALL BCGetCountRows(const t_BarCode* pBarCode);

TBARCODEDLL_API DOUBLE TECIT_STDCALL BCGetModuleWidth(t_BarCode* pBarCode, LPRECT pRect, HDC hDC, e_MUnit eUnit);
TBARCODEDLL_API DOUBLE TECIT_STDCALL BCGetBarcodeWidth(t_BarCode* pBarCode, LPRECT pRect, HDC hDC, e_MUnit eUnit);
TBARCODEDLL_API DOUBLE TECIT_STDCALL BCGetBarcodeHeight(t_BarCode* pBarCode, LPRECT pRect, HDC hDC, e_MUnit eUnit);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCGetBarcodeSize(t_BarCode* pBarCode, LPRECT pRect, HDC hDC, e_MUnit eUnit, DOUBLE* pdWidth, DOUBLE* pdHeight);
TBARCODEDLL_API DOUBLE TECIT_STDCALL BCGetTextAreaHeight(t_BarCode* pBarCode, LPRECT pRect, HDC hDC, e_MUnit eUnit);


//
// ----- Barcode > Module Width and Barcode Quality 
//
TBARCODEDLL_API LONG TECIT_STDCALL BCGetDPIHorz(t_BarCode* pBarCode);
TBARCODEDLL_API LONG TECIT_STDCALL BCGetDPIVert(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetDPI(t_BarCode* pBarCode, LONG nDPIHorz, LONG nDPIVert);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGetIgnoreDpiFromDC(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetIgnoreDpiFromDC(t_BarCode* pBarCode, BOOL bIgnore);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGetModWidth(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetModWidth(t_BarCode* pBarCode, LPCSTR szModWidth);

TBARCODEDLL_API LONG TECIT_STDCALL BCGetModWidthN(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetModWidthN(t_BarCode* pBarCode, LONG moduleWidth);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGetMustFit(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetMustFit(t_BarCode* pBarCode, BOOL bMustFit);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGetOptResolution(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetOptResolution(t_BarCode* pBarCode, BOOL bOpt);

TBARCODEDLL_API e_SizeMode TECIT_STDCALL BCGetSizeMode(const t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetSizeMode(t_BarCode* pBarCode, e_SizeMode mode);

TBARCODEDLL_API e_Decoder TECIT_STDCALL BCGetDecoder(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetDecoder(t_BarCode* pBarCode, e_Decoder eDecoder);

TBARCODEDLL_API LONG TECIT_STDCALL BCGetBarWidthReduction(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetBarWidthReduction(t_BarCode* pBarCode, LONG nFactor);

TBARCODEDLL_API LONG TECIT_STDCALL BCGetQuality(t_BarCode* pBarCode, HDC hDC, RECT* pRect);



//____________________________________________________________________________
//
// Drawing and Saving Barcodes  
//____________________________________________________________________________
//

//
// ----- Drawing > GDI
//
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetDCConversion(t_BarCode* pBarCode, BOOL bConvertDC);
TBARCODEDLL_API BOOL TECIT_STDCALL BCGetDCConversion(t_BarCode* pBarCode);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGetDrawMode(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetDrawMode(t_BarCode* pBarCode, BOOL bUseGDIRect);

TBARCODEDLL_API e_DrawMode TECIT_STDCALL BCGetDrawModeExt(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetDrawModeExt(t_BarCode* pBarCode, e_DrawMode eMode);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCDraw(t_BarCode* pBarCode, HDC hDC, RECT* pRect);




#ifdef TEC_WIN32
//
// ----- Drawing > GDI > Clipboard
//
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCCopyToClipboard(t_BarCode* pBarCode, LONG nWidth, LONG nHeight);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCCopyToClipboardEx(t_BarCode* pBarCode, HDC hDC, LONG nWidth, LONG nHeight, 
                                                        BOOL fTransparent, COLORREF crBkCol, LPCSTR szFileName);

//
// ----- Drawing > GDI > Enhanced Metafile
//
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCGetEnhMetaFile(t_BarCode* pBarCode, HENHMETAFILE* phEMF, LONG nWidth, LONG nHeight);  
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCGetEnhMetaFileEx(t_BarCode* pBarCode, HENHMETAFILE* phEMF, HDC hDC, 
                                                       LONG nWidth, LONG nHeight, BOOL fTransparent);
//
// ----- Drawing > GDI > Image
//
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSaveImage(t_BarCode* pBarCode, LPCSTR lpszFileName, 
                         e_IMType eImageType, LONG lXSize, LONG lYSize, LONG lXRes, LONG lYRes);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSaveImageEx(t_BarCode* pBarCode, HDC hDC, LPCSTR lpszFileName, e_IMType eImageType, 
                                                  LONG lQuality, LONG lXSize, LONG lYSize, LONG lXRes, LONG lYRes);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSaveImageToBuffer(t_BarCode* pBarCode, LPBYTE* lpBuffer, e_IMType eImageType, 
                        LONG lXSize, LONG lYSize, LONG lXRes, LONG lYRes);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSaveImageToBufferEx(t_BarCode* pBarCode, HDC hDC, LPBYTE* lpBuffer, 
                                                          e_IMType eImageType, LONG lQuality, LONG lXSize, LONG lYSize, 
                                                          LONG lXRes, LONG lYRes);
#endif // TEC_WIN32


//
// ----- Drawing > Bitmap
//
TBARCODEDLL_API BOOL TECIT_STDCALL BCIsImageMagickAvailable();
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCBitmapToFile(t_BarCode* 	pBarCode, LPCSTR szFilename, LPCRECT pRect);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCBitmapToMemory(t_BarCode* 	pBarCode, VOID* pHandle, LPCSTR pszFormat, 
                                                     INT* pnSize, LPCRECT pRect);


//
// ----- Drawing > PCL
//
TBARCODEDLL_API e_PCLMode TECIT_STDCALL BCGetPCLMode(const t_BarCode* pBarcode);
TBARCODEDLL_API VOID TECIT_STDCALL BCSetPCLMode(t_BarCode* pBarcode, e_PCLMode mode);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCPCLToFile(t_BarCode* pBarCode, LPCSTR szFilename, LPCRECT pRect);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCPCLToFileExt(t_BarCode* pBarCode, LPCSTR szFilename, LPCRECT pRect, 
                                                   BOOL bRelPos);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCPCLToMemory(t_BarCode* pBarCode, VOID* pHandle, INT nSize, LPCRECT pRect);  
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCPCLToMemoryExt(t_BarCode* pBarCode, VOID* pHandle, INT* pnSize, 
                                                     LPCRECT pRect, BOOL bRelPos);


//
// ----- Drawing > PDF
//
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCPDFToFile(t_BarCode* pBarCode, LPCSTR szFilename, LPCRECT pRect);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCPDFToMemory(t_BarCode* pBarCode, VOID* pHandle, INT* pnSize, 
                                                  LPCRECT pRect);


//
// ----- Drawing > Postscript
//
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCPostscriptToFile(t_BarCode* pBarCode, LPCSTR szFilename, LPCRECT pRect);  
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCPostscriptToMemory(t_BarCode* pBarCode, VOID* pHandle, INT nSize, LPCRECT pRect);  
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCPostscriptToMemoryExt(t_BarCode* pBarCode, VOID* pHandle, INT* pnSize, 
                                                            LPCRECT pRect, BOOL bIncludeMacros);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCGetPostscriptMacros(LPSTR pszMacros, INT* pnSize);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGet_EPS_SubstwDeviceFonts(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_EPS_SubstwDeviceFonts(t_BarCode* pBarCode, BOOL bSubwDevFnts);

//
// ----- Drawing > Callback
//
TBARCODEDLL_API fn_DrawRow TECIT_STDCALL BCGetFuncDrawRow(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetFuncDrawRow(t_BarCode* pBarCode, fn_DrawRow fn);

TBARCODEDLL_API fn_DrawBar TECIT_STDCALL BCGetFuncDrawBar(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetFuncDrawBar(t_BarCode* pBarCode, fn_DrawBar fn);

TBARCODEDLL_API fn_DrawText TECIT_STDCALL BCGetFuncDrawText(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetFuncDrawText(t_BarCode* pBarCode, fn_DrawText fn);

TBARCODEDLL_API LPVOID TECIT_STDCALL BCGetCBData(t_BarCode* pBarCode);
TBARCODEDLL_API VOID TECIT_STDCALL BCSetCBData(t_BarCode* pBarCode, LPVOID pData);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCDrawCB(t_BarCode* pBarCode, HDC hDC, RECT* pRect);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGetMetaData(t_BarCode* pBarCode);



//____________________________________________________________________________
//
// Multiple Barcodes
//____________________________________________________________________________
//

TBARCODEDLL_API BOOL TECIT_STDCALL BCGet_MultiBC_Enabled(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MultiBC_Enabled(t_BarCode* pBarCode, BOOL bOn);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_MultiBC_Rows(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MultiBC_Rows(t_BarCode* pBarCode, INT nNumRows);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_MultiBC_Columns(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MultiBC_Columns(t_BarCode* pBarCode, INT nNumCols);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_MultiBC_HDist(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MultiBC_HDist(t_BarCode* pBarCode, LONG nDistance);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_MultiBC_VDist(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MultiBC_VDist(t_BarCode* pBarCode, LONG nDistance);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_MultiBC_DataLimit(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MultiBC_DataLimit(t_BarCode* pBarCode, LONG nLimit);

TBARCODEDLL_API e_StructuredAppendMode TECIT_STDCALL BCGet_MultiBC_StructApp(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MultiBC_StructApp(t_BarCode* pBarCode, e_StructuredAppendMode eSAM);

TBARCODEDLL_API e_DynamicBoundingRect TECIT_STDCALL BCGet_MultiBC_DynamicBoundingRect(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MultiBC_DynamicBoundingRect(t_BarCode* pBarCode, e_DynamicBoundingRect eBoundingRect);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BC_MultiBC_CalculateLayout(t_BarCode* pBarCode, HDC hDC, LPCRECT pRect, INT* nRequiredWidth, INT* nRequiredHeight);


//____________________________________________________________________________
//
// Error Handling
//____________________________________________________________________________
//

TBARCODEDLL_API VOID TECIT_STDCALL BCGetErrorText(ERRCODE eCode, LPSTR szText, size_t nSize);
TBARCODEDLL_API VOID TECIT_STDCALL BCGetErrorTextExt(t_BarCode* pBarCode, ERRCODE eCode, LPSTR szText, size_t nSize);
TBARCODEDLL_API INT TECIT_STDCALL BCGet_InvalidDataPos(t_BarCode* pBarCode);



//____________________________________________________________________________
//
// 2D Barcodes and Special Symbologies
//___________________________________________________________________________
//

//
// ----- Special Barcodes > Code 2 of 5 Interleaved 
//
TBARCODEDLL_API BOOL TECIT_STDCALL BCGetAutoCorrect(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSetAutoCorrect(t_BarCode* pBarCode, BOOL bAutoCorrect);


//
// ----- Special Barcodes > PDF417 and MicroPDF 
//
TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_Rows(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_Rows(t_BarCode* pBarCode, LONG nRows);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_Columns(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_Columns(t_BarCode* pBarCode, LONG nColumns);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_ECLevel(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_ECLevel(t_BarCode* pBarCode, LONG nLevel);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_RowHeight(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_RowHeight(t_BarCode* pBarCode, LONG nHeight);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_PDF417_RowColRatio(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_RowColRatio(t_BarCode* pBarCode, LPCSTR szRatio);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_CodeWords(t_BarCode* pBarCode);

//
// ----- Special Barcodes > PDF417 and Micro PDF > Macro PDF
//
TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_SegIndex(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_SegIndex(t_BarCode* pBarCode, LONG nSegInx);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_PDF417_FileID(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_FileID(t_BarCode* pBarCode, LPCSTR szFileID);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGet_PDF417_SegLast(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_SegLast(t_BarCode* pBarCode, BOOL bSegLast);

TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_FileName(t_BarCode* pBarCode, LPCSTR szFileName);
TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_PDF417_FileName(t_BarCode* pBarCode);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_SegCount(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_SegCount(t_BarCode* pBarCode, LONG nSegCount);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_TimeStamp(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_TimeStamp(t_BarCode* pBarCode, LONG nTimeStamp);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_PDF417_Sender(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_Sender(t_BarCode* pBarCode, LPCSTR szSender);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_PDF417_Addressee(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_Addressee(t_BarCode* pBarCode, LPCSTR szAddressee);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_FileSize(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_FileSize(t_BarCode* pBarCode, LONG nFileSize);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_PDF417_CheckSum(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_PDF417_CheckSum(t_BarCode* pBarCode, LONG nCheckSum);


//
// ----- Special Barcodes > PDF417 and Micro PDF > Micro PDF
//
TBARCODEDLL_API e_MPDFMode TECIT_STDCALL BCGet_MPDF417_Mode(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MPDF417_Mode(t_BarCode* pBarCode, e_MPDFMode eMode);

TBARCODEDLL_API e_MPDFVers TECIT_STDCALL BCGet_MPDF417_Version(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_MPDF417_Version(t_BarCode* pBarCode, e_MPDFVers eVersion);

TBARCODEDLL_API LPCSTR* TECIT_STDCALL BCGet_MPDF417_Versions();
TBARCODEDLL_API LONG TECIT_STDCALL BCGet_MPDF417_VersionCount();



//
// ----- Special Barcodes > MaxiCode
//
TBARCODEDLL_API LONG TECIT_STDCALL BCGet_Maxi_Mode(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_Maxi_Mode(t_BarCode* pBarCode, LONG nMode);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_Maxi_AppendSum(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_Maxi_Append(t_BarCode* pBarCode, LONG nSum, LONG nIndex);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_Maxi_AppendIndex(t_BarCode* pBarCode);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_Maxi_UnderCut(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_Maxi_UnderCut(t_BarCode* pBarCode, LONG nUndercut);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGet_Maxi_UsePreamble(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_Maxi_UsePreamble(t_BarCode* pBarCode, BOOL bUse, LPCSTR szDate);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_Maxi_PreambleDate(t_BarCode* pBarCode);
TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_Maxi_SCMServClass(t_BarCode* pBarCode);
TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_Maxi_SCMCountryCode(t_BarCode* pBarCode);
TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_Maxi_SCMPostalCode(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_Maxi_SCM(t_BarCode* pBarCode, LPCSTR szServiceClass,
                                                   LPCSTR szCountryCode, LPCSTR szPostalCode);

//
// ----- Special Barcodes > Data Matrix 
//
TBARCODEDLL_API e_DMSizes TECIT_STDCALL BCGet_DM_Size(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_DM_Size(t_BarCode* pBarCode, e_DMSizes eSize);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGet_DM_Rectangular(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_DM_Rectangular(t_BarCode* pBarCode, BOOL bRect);

TBARCODEDLL_API e_DMFormat TECIT_STDCALL BCGet_DM_Format(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_DM_Format(t_BarCode* pBarCode, e_DMFormat eFormat);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_DM_AppendSum(t_BarCode* pBarCode);
TBARCODEDLL_API LONG TECIT_STDCALL BCGet_DM_AppendIndex(t_BarCode* pBarCode);
TBARCODEDLL_API LONG TECIT_STDCALL BCGet_DM_AppendFileID(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_DM_Append(t_BarCode* pBarCode, LONG nSum, LONG nIndex, LONG nFileID);
TBARCODEDLL_API BOOL TECIT_STDCALL BC_DM_IsAppendAllowed(e_DMFormat eFormat);
TBARCODEDLL_API LPCSTR* TECIT_STDCALL BCGetDataMatrixSizes();
TBARCODEDLL_API LONG TECIT_STDCALL BCGetDataMatrixSizesCount();


//
// ----- Special Barcodes > QR-Code
//
TBARCODEDLL_API e_QRVersion TECIT_STDCALL BCGet_QR_Version(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_QR_Version(t_BarCode* pBarCode, e_QRVersion eVersion);

TBARCODEDLL_API e_QRFormat TECIT_STDCALL BCGet_QR_Format(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_QR_Format(t_BarCode* pBarCode, e_QRFormat eFormat);

TBARCODEDLL_API LPCSTR TECIT_STDCALL BCGet_QR_FmtAppIndicator(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_QR_FmtAppIndicator(t_BarCode* pBarCode, LPCSTR szIndicator);

TBARCODEDLL_API e_QRECLevel TECIT_STDCALL BCGet_QR_ECLevel(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_QR_ECLevel(t_BarCode* pBarCode, e_QRECLevel eECLevel);

TBARCODEDLL_API e_QRMask TECIT_STDCALL BCGet_QR_Mask(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_QR_Mask(t_BarCode* pBarCode, e_QRMask eMask);

TBARCODEDLL_API e_QRMBCompaction TECIT_STDCALL BCGet_QR_KanjiChineseCompaction (t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_QR_KanjiChineseCompaction (t_BarCode* pBarCode, e_QRMBCompaction eCompact);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_QR_AppendSum(t_BarCode* pBarCode);
TBARCODEDLL_API LONG TECIT_STDCALL BCGet_QR_AppendIndex(t_BarCode* pBarCode);
TBARCODEDLL_API BYTE TECIT_STDCALL BCGet_QR_AppendParity(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_QR_Append(t_BarCode* pBarCode, LONG nSum, LONG nIndex, BYTE bParity);

TBARCODEDLL_API BYTE TECIT_STDCALL BCCalcStructApp_Parity(LPCSTR szIntData, LONG nIntData);
TBARCODEDLL_API BYTE TECIT_STDCALL BCCalcStructApp_ParityW(const LPWORD pwIntData, LONG nIntData);

TBARCODEDLL_API LPCSTR* TECIT_STDCALL BCGetQRCodeVersions();
TBARCODEDLL_API LONG TECIT_STDCALL BCGetQRCodeVersionCount();


//
// ----- Special Barcodes > Codablock F 
//
TBARCODEDLL_API e_CBFFormat TECIT_STDCALL BCGet_CBF_Format(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_CBF_Format(t_BarCode* pBarCode, e_CBFFormat eFormat);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_CBF_Columns(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_CBF_Columns(t_BarCode* pBarCode, LONG nColumns);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_CBF_Rows(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_CBF_Rows(t_BarCode* pBarCode, LONG nRows);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_CBF_RowHeight(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_CBF_RowHeight(t_BarCode* pBarCode, LONG nHeight);

TBARCODEDLL_API LONG TECIT_STDCALL BCGet_CBF_RowSeparatorHeight(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_CBF_RowSeparatorHeight(t_BarCode* pBarCode, LONG nHeight);

//
// ----- Special Barcodes > EAN / UCC Composite Symbology
//
TBARCODEDLL_API e_CCType TECIT_STDCALL BCGet_2DCompositeComponent(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_2DCompositeComponent(t_BarCode* pBarCode, e_CCType eCCType);

TBARCODEDLL_API BOOL TECIT_STDCALL BCGet_CompSym_IsCCPresent(t_BarCode* pBarCode);
TBARCODEDLL_API BOOL TECIT_STDCALL BCGet_CompSym_IsCCAvailable(t_BarCode* pBarCode, e_CCType eCCType);
TBARCODEDLL_API BOOL TECIT_STDCALL BCGet_CompSym_ErrorInCC(t_BarCode* pBarCode);

TBARCODEDLL_API BOOL TECIT_STDCALL BCIsCompositeAllowed(e_BarCType barcodeType);
TBARCODEDLL_API BOOL TECIT_STDCALL BCIsCompositeComponentAllowed(e_BarCType barcodeType, e_CCType componentType);


//
// ----- Special Barcodes > RSS (Reduced Space Symbology)
//
TBARCODEDLL_API LONG TECIT_STDCALL BCGet_RSS_SegmPerRow(t_BarCode* pBarCode);
TBARCODEDLL_API ERRCODE TECIT_STDCALL BCSet_RSS_SegmPerRow(t_BarCode* pBarCode, LONG nSegmPerRow);


#ifdef __cplusplus
  }
#endif

#endif // TBARCODE_HEADER
